"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var PIXI = _interopRequireWildcard(require("pixi.js"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * class for renderer
 */
class QinRenderer {
  /**
   * init renderer for engine
   * @param props {RendererPropsType}
   * @param props._core {QinCore} engine core
   * @param props._canvas {HTMLElement} HTMLElement instance which will contain your renderer
   */
  constructor(props) {
    _defineProperty(this, "_core", void 0);

    _defineProperty(this, "_canvasContainer", void 0);

    _defineProperty(this, "_controller", void 0);

    _defineProperty(this, "_renderer", void 0);

    _defineProperty(this, "_resources", void 0);

    _defineProperty(this, "_onAssetLoadingFinish", void 0);

    this._core = props.core;
    this._canvasContainer = props.element;
    this._controller = null;

    this._onAssetLoadingFinish = () => {};

    this._initRenderer(props);

    this._initAssetLoader();
  }
  /**
   * init renderer and stage
   * @param props {RendererPropsType}
   * @private
   */


  _initRenderer(props) {
    const {
      width,
      height
    } = props;
    this._renderer = new PIXI.Application(width, height, {
      backgroundColor: 0xeeeeee
    }); // this._controller = new Controller({
    // 	mouse: new Mouse({
    // 		hitArea: new PIXI.Rectangle(0, 0, width, height),
    // 	}).init(),
    // });
    // this._stageAgent = new StageAgent({renderer: this._renderer, controller: this._controller});
    //
    // this._stageAgent.init();

    this._canvasContainer.appendChild(this._renderer.view);

    this._renderer.view.addEventListener('contextmenu', e => {
      e.preventDefault();
    });
  }
  /**
   * init asset loader for loading asset files
   * @todo show progress information
   * @private
   */


  _initAssetLoader() {
    let loader = PIXI.loader;
    loader.onProgress.add(e => {//console.log(e.progress);
    });
    loader.onComplete.add((loader, resources) => {
      this._resources = resources;

      this._onAssetLoadingFinish();
    });
  }

  _setAssetLoadingListener(onFinish) {
    this._onAssetLoadingFinish = onFinish;
  }
  /**
   * loading asset files to memory
   * @param assetsSet {object} static object contain files information such as path, name etc.
   * @private
   */


  _prepareAssets(assetsSet) {
    let loader = PIXI.loader;
    loader.reset();

    for (let assetsData of assetsSet) {
      for (const asset in assetsData) {
        if (assetsData[asset].IS_CONTAIN_ANIMATION) {
          for (let animation in assetsData[asset].DATA) {
            loader.add(assetsData[asset].DATA[animation].NAME, assetsData[asset].DATA[animation].PATH);
          }
        } else {
          loader.add(assetsData[asset].DATA.NAME, assetsData[asset].DATA.PATH);
        }
      }
    }

    loader.load();
  }

  addActor(actor) {
    this._renderer.stage.addChild(actor);
  }

  renderScene(scene) {
    scene._setRenderer(this);

    scene.onFinish(); // this._setAssetLoadingListener(scene.onAssetsFinish());
    // this._prepareAssets(scene.getAssetsDate());

    return this;
  }

  render() {}

}

var _default = QinRenderer;
exports.default = _default;